Polyhedron container class, which is accessible by the final users upon call
ken4rab
file.idPolyhedron file.id
statePolyhedron state
loggerclass logger
new()Create a polyhedronState object
Polyhedron$new(file.id, state = NULL)file.idthe file id
statepolyhedron state object
A new Polyhedron object.
scrapeNetlib()scrape Netlib polyhedron definition
Polyhedron$scrapeNetlib(netlib.p3.lines)netlib.p3.linesvector with netlib definition lines
A new PolyhedronStateDefined object.
scrapeDmccooey()scrape Dmccooey polyhedron definition
Polyhedron$scrapeDmccooey(polyhedra.dmccooey.lines)polyhedra.dmccooey.linesvector with Dmccooey definition lines
A new PolyhedronStateDefined object.
deserialize()deserialize a polyhedron state definition
Polyhedron$deserialize(serialized.polyhedron)serialized.polyhedrona serialized version of a polyhedron state
A new PolyhedronStateDefined object.
getName()get Polyhedron name
Polyhedron$getName()string with polyhedron name
getState()Gets polyhedron state
Polyhedron$getState()A new PolyhedronState object.
getSolid()Gets a solid definition
Polyhedron$getSolid()A list of vertex vectors composing polyhedron faces.
isChecked()checks Edges consistency
Polyhedron$isChecked()A boolean value
getRGLModel()Return an 'rgl' model with an optional transformation described by transformation.matrix parameter
Polyhedron$getRGLModel(transformation.matrix = NULL)transformation.matrixtransformation matrix parameter
An tmesh3d object
exportToXML()exports an XML definition of current polyhedron
Polyhedron$exportToXML()A character object with the XML definition
getErrors()returns the errors found when processing current polyhedron
Polyhedron$getErrors()a data.frame with polyhedron errors
checkProperties()check properties of current polyhedron
Polyhedron$checkProperties(expected.vertices, expected.faces)expected.verticesexpected vertices number
expected.facesexpected faces number
Unmodified polyhedron object
clone()The objects of this class are cloneable with this method.
Polyhedron$clone(deep = FALSE)deepWhether to make a deep clone.